@@ -3,7 +3,7 @@ import json
 import pandas 
 
 def health(token, ticker): 
-    url = "https://spawnerapi.com/health/" + token
+    url = "https://spawnerapi.com/health/" + ticker + "/" + token
     response = requests.get(url).json()
     return response.read_json()
 
@@ -15,20 +15,20 @@ def fundamentals(token):
 def macro(token): 
     url = "https://spawnerapi.com/macro/" + token
     response = requests.get(url).json()
-    return response.read_json()
+    return response
 
 def rsi(token, ticker): 
     url = "https://spawnerapi.com/rsi/" + token
     response = requests.get(url).json()
-    return response.read_json()
+    return response
 
 def stochastic(token, ticker): 
     url = "https://spawnerapi.com/stochastic/" + token
     response = requests.get(url).json()
-    return response.read_json()
+    return response
 
 def kaufman(token): 
     url = "https://spawnerapi.com/kaufman/" + token
     response = requests.get(url).json()
-    return response.read_json()
+    return response
                 
\ No newline at end of file
